@@ -25,7 +25,7 @@ class Spider;
 class SpiderSolver : public Solver
 {
 public:
-    SpiderSolver(const Spider *dealer);
+    explicit SpiderSolver(const Spider *dealer);
     virtual int get_possible_moves(int *a, int *numout);
     virtual bool isWon();
     virtual void make_move(MOVE *m);
